<?php

/**
 * JCH Optimize - Aggregate and minify external resources for optmized downloads
 * 
 * @author Samuel Marshall <sdmarshall73@gmail.com>
 * @copyright Copyright (c) 2010 Samuel Marshall
 * @license GNU/GPLv3, See LICENSE file
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

include_once(Mage::getModuleDir('Module', 'CodeAlfa_JchOptimize') . '/lib/jchoptimize/loader.php');

abstract class CodeAlfa_JchOptimize_Block_Form_Auto_Abstract extends Mage_Adminhtml_Block_System_Config_Form_Field
{

        abstract protected function getButtons();

        protected function _getElementHtml(Varien_Data_Form_Element_Abstract $element)
        {
                return JchOptimizeAdmin::generateIcons($this->getButtons());
        }

        public function render(Varien_Data_Form_Element_Abstract $element)
        {
                
                
                
                $id = $element->getHtmlId();

                if ($element->getTooltip())
                {
                        $html = '<td class="label with-tooltip"><label for="' . $id . '" style="float: left; width: auto;">' . $element->getLabel() . '</label>'
                                
                                . '<div class="field-tooltip"><div>' . $element->getTooltip() . '</div></div>'
                                . '</td>';
                }
                else
                {
                        $html = '<td class="label"><label for="' . $id . '">' . $element->getLabel() . '</label></td>';
                }

                //$isDefault = !$this->getRequest()->getParam('website') && !$this->getRequest()->getParam('store');
                $isMultiple = $element->getExtType() === 'multiple';

                // replace [value] with [inherit]
                $namePrefix = preg_replace('#\[value\](\[\])?$#', '', $element->getName());

                $options = $element->getValues();

                $addInheritCheckbox = false;
                if ($element->getCanUseWebsiteValue())
                {
                        $addInheritCheckbox = true;
                        $checkboxLabel      = $this->__('Use Website');
                }
                elseif ($element->getCanUseDefaultValue())
                {
                        $addInheritCheckbox = true;
                        $checkboxLabel      = $this->__('Use Default');
                }

                if ($addInheritCheckbox)
                {
                        $inherit = $element->getInherit() == 1 ? 'checked="checked"' : '';
                        if ($inherit)
                        {
                                $element->setDisabled(true);
                        }
                }

                $html .= '<td colspan="3">';
                $html .= $this->_getElementHtml($element);

                if ($element->getComment())
                {
                        $html.= '<p class="note" style="display: inline-block;"><span>' . $element->getComment() . '</span></p>';
                }
                
                $html.= '</td>';

                return $this->_decorateRowHtml($element, $html);
        }
}
